==> TopdataTopFeedSW6-v7.0.5.zip: TopdataTopFeedSW6/README.md <==
# Topdata TopFeed for Shopware 6

## Description
Topdata TopFeed is a Shopware 6 plugin that enables automatic synchronization of product data between your Shopware store and TopData's cloud-based web service. This plugin enhances your product pages with rich, up-to-date information and improves cross-selling capabilities.

## Features
- Automatic product data synchronization (name, description, brand, EAN, MPN, images, specifications)
- Enhanced product relationships (variants, alternates, bundles, accessories)
- Compatible devices display
- Customizable product detail page with additional tabs and information
- Configurable cross-selling features
- Support for color and capacity variants

## Requirements
- Shopware 6.5.* or 6.6.*
- TopData Connector for Shopware 6 (version 1.2.5 or higher)

## Installation
1. Install the TopData Connector for Shopware 6 if you haven't already.
2. Upload the plugin files to your Shopware installation's `custom/plugins` directory.
3. Install and activate the plugin through the Shopware Administration panel.

## Configuration
After installation, you can configure the plugin in the Shopware Administration panel under Settings > System > Plugins > Topdata TopFeed.

Configuration options include:
- Import settings for various product data types
- Display settings for product detail pages
- Cross-selling options
- Product menu and list display options

## Usage
Once configured, the plugin will automatically sync product data from TopData's service. The enhanced product information and relationships will be visible on your store's product pages.

## Support
For support and more information, please visit: https://www.topdata.de/topfeed

## About TopData
TopData Software GmbH specializes in providing comprehensive product data solutions for e-commerce platforms. Visit [www.topdata.de](https://www.topdata.de) for more information about our services.

## License
This plugin is released under the MIT License. See the LICENSE file for more details.

==> TopdataTopFeedSW6-v7.0.9.zip: TopdataTopFeedSW6/README.md <==
# Topdata TopFeed for Shopware 6

## Description
Topdata TopFeed is a Shopware 6 plugin that enables automatic synchronization of product data between your Shopware store and TopData's cloud-based web service. This plugin enhances your product pages with rich, up-to-date information and improves cross-selling capabilities.

## Features
- Automatic product data synchronization (name, description, brand, EAN, MPN, images, specifications)
- Enhanced product relationships (variants, alternates, bundles, accessories)
- Compatible devices display
- Customizable product detail page with additional tabs and information
- Configurable cross-selling features
- Support for color and capacity variants

## Requirements
- Shopware 6.5.* or 6.6.*
- TopData Connector for Shopware 6 (version 7.0.0 or later)

## Installation
1. Install the TopData Connector for Shopware 6 if you haven't already.
2. Upload the plugin files to your Shopware installation's `custom/plugins` directory.
3. Install and activate the plugin through the Shopware Administration panel.

## Configuration
After installation, you can configure the plugin in the Shopware Administration panel under Settings > System > Plugins > Topdata TopFeed.

Configuration options include:
- Import settings for various product data types
- Display settings for product detail pages
- Cross-selling options
- Product menu and list display options

## Usage
Once configured, the plugin will automatically sync product data from TopData's service. The enhanced product information and relationships will be visible on your store's product pages.

## Support
For support and more information, please visit: https://www.topdata.de/topfeed

## About TopData
TopData Software GmbH specializes in providing comprehensive product data solutions for e-commerce platforms. Visit [www.topdata.de](https://www.topdata.de) for more information about our services.

## License
This plugin is released under the MIT License. See the LICENSE file for more details.
